package ShareStuff::UI;
use strict;
use warnings;

use Apache::Constants qw( :common );
use Template qw( :template );
use CGI;
use OpenSRF::EX qw(:try);
use OpenSRF::System;
use ShareStuff::CStoreEditor qw/:funcs/;


# set the bootstrap config and template include directory when
# this module is loaded
my $bootstrap;
my $ssl_off;

sub import {
    my $self = shift;
    $bootstrap = shift;
    $ssl_off = shift;
}


sub child_init {
    OpenSRF::System->bootstrap_client( config_file => $bootstrap );
    ShareStuff::CStoreEditor::init();
    return OK;
}

# we epxect a PerlSetVar of ss_templates pointing to the location of the TT files
sub handler {
    my %env = ();

    $env{r} = shift;
    $env{cgi} = new CGI;

    $env{authtoken} = $cgi->cookie('ses') || $cgi->param('ses');
    $env{user} = verify_login($env{authtoken});
    $env{cstore} = new_editor( authtoken => $env{authtoken} );


    $env{file} = $env{r}->path_info;
    $env{file} =~ s[^/][];

    $env{api} = 0;
    if ($env{file} =~ /^api/) {
        $env{file} =~ s[^api/][];
        $env{api} = 1;
    }

    my $template = Template->new({ 
        VARIABLES     => \%env,
        INCLUDE_PATH  => $ss_templates,
        OUTPUT        => $env{r},     # direct output to Apache request
    });

    $evn{r}->content_type('text/html') if (!$env{api});
    $evn{r}->content_type('text/json') if ($env{api});
    $evn{r}->send_http_header;

    $template->process($env{file}, $env) || return fail($env{r}, SERVER_ERROR, $template->error());

    return OK;
}

sub fail {
    my ($r, $status, $message) = @_;
    $r->log_reason($message, $r->filename);
    return $status;
}

# returns the user object if the session is valid, 0 otherwise
sub verify_login {
    my $auth_token = shift;
    return undef unless $auth_token;

    my $user = OpenSRF::AppSession
        ->create("sharestuff.auth")
        ->request( "sharestuff.auth.session.retrieve", $auth_token )
        ->gather(1);

    if (ref($user) eq 'HASH' && $user->{ilsevent} == 1001) {
        return undef;
    }

    return $user if ref($user);
    return undef;
}

1;
